Exceptions in Async PRAW
========================

In addition to exceptions under the ``asyncpraw.exceptions`` namespace shown below,
exceptions might be raised that inherit from ``asyncprawcore.AsyncPrawcoreException``.
Please see the following resource for information on those exceptions:
https://github.com/praw-dev/asyncprawcore/blob/master/asyncprawcore/exceptions.py

asyncpraw.exceptions
--------------------

.. automodule:: asyncpraw.exceptions
    :inherited-members:
